#!/usr/bin/python

# File...... rfid-demo.py
# Purpose... Demonstration code for the Parallax RFID Card Reader USB Module (#28340)
# Author.... Joe Grand, Grand Idea Studio, Inc. [www.grandideastudio.com]
# E-mail.... support@parallax.com
# Updated... 30 June 2016

# This program demonstrates the capabilities of the Parallax RFID Card Reader
# USB Module (#28340).
#
# Compatible with EM Microelectronic EM4100-family 125kHz tags.
#
# Tested with Python 2.7.11 w/ pySerial 3.0.1 on Mac OS X 10.11.5 and Windows 7 SP1.

class Unbuffered(object):
    def __init__(self, stream):
        self.stream = stream
    def write(self, data):
        self.stream.write(data)
        self.stream.flush()
    def __getattr__(self, attr):
        return getattr(self.stream, attr)

import os
import sys
import serial	# http://pyserial.sourceforge.net/

# change port name to match your particular instance
port = "/dev/tty.usbserial-A1014JFW"    # OS X
#port = "//./COM3"                      # Windows

ser = serial.Serial(port, 2400, timeout = None)    # open serial port
sys.stdout = Unbuffered(sys.stdout)                # open stdout in unbuffered mode (automatically flush after each print operation)

print "Parallax RFID Card Reader USB Module Demonstration\n"

print "Enabling the module...",
ser.setDTR(True)	# the module is enabled by asserting DTR
print "Success!"

print "Reading tag's unique serial number...",
while True:
  buf = ser.read(12)  				# get bytes (will block until received)  
  if buf[0] == chr(0x0A):			# if valid data received with no error, continue
    break
for i in range(1,len(buf)-1):		# display data (ignore final 0x0D byte sent by the reader)
  sys.stdout.write(buf[i])
print ""

print "Disabling the module...",
ser.setDTR(False)	# the module is disabled by de-asserting DTR
print "Success!"

ser.close()
